"use client"
import React, { useState, useRef } from 'react';

function Sound(props) {

  const [isPlaying, setIsPlaying] = useState(false);
  const [volume, setVolume] = useState(0); // Initial volume is set to 0.5 (50%)
  const audioRef = useRef(null);

  const togglePlayPause = () => {
  	console.log('togglePlayPause');
    if (audioRef.current.paused) {
      audioRef.current.play();
    } else {
      audioRef.current.pause();
    }
  };

  const handleVolumeChange = (event) => {
  	if (!isPlaying) {
  		togglePlayPause();
  	}
  	if ( isPlaying && (event.target.value === 0 || event.target.value === "0")) {
  		togglePlayPause();
  	}else{
  			audioRef.current.play()
  	}
    const newVolume = event.target.value;
    audioRef.current.volume = newVolume;
    setVolume(newVolume);
  };

  return (
  	<>
  	     {
  	      	props.audio ? (
  	      			<>
									<div className="p-8 bg-accent color-accent-content rounded-lg shadow-md m-3 w-[10em] sm:w-auto h-auto space-y-4">
											<audio id={'audio-'+props.name} ref={audioRef} loop>
												<source src={props.audio} type="audio/mpeg" />
												Your browser does not support the audio element.
											</audio>
											{
												typeof props.img === "string" ?
													(
														<img src={props.img} className="fill-accent-content w-24 h-24 m-auto" />
													)
												:
													props.img
											}
											<div className="flex flex-col space-y-2 items-center justify-center content-center">
													 <span className="text-xl font-bold">{props.name}</span>
													 <h1 id={'val-'+props.name} className="text-lg badge badge-lg badge-primary w-full">{Math.floor(volume*100) ?? 0}%</h1>
											</div>
											<input
												id={'seek-'+props.name}
												type="range"
												min="0"
												max="1"
												step="0.01"
												value={volume}
												onChange={handleVolumeChange}
												className="range w-[6em] sm:w-auto"
											/>
									</div>
  	      			</>
  	      	):null
  	     }
  	</>
  );
}

export default Sound;

